==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/Glue/GetCatalogImportStatus.pm <==

package Paws::Glue::GetCatalogImportStatus;
  use Moose;
  has CatalogId => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetCatalogImportStatus');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::GetCatalogImportStatusResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::GetCatalogImportStatus - Arguments for method GetCatalogImportStatus on Paws::Glue

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetCatalogImportStatus on the 
AWS Glue service. Use the attributes of this class
as arguments to method GetCatalogImportStatus.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetCatalogImportStatus.

As an example:

  $service_obj->GetCatalogImportStatus(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 CatalogId => Str

The ID of the catalog to migrate. Currently, this should be the AWS
account ID.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetCatalogImportStatus in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/Glue/GetCatalogImportStatus.pm <==

package Paws::Glue::GetCatalogImportStatus;
  use Moose;
  has CatalogId => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetCatalogImportStatus');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::GetCatalogImportStatusResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::GetCatalogImportStatus - Arguments for method GetCatalogImportStatus on L<Paws::Glue>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetCatalogImportStatus on the
L<AWS Glue|Paws::Glue> service. Use the attributes of this class
as arguments to method GetCatalogImportStatus.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetCatalogImportStatus.

=head1 SYNOPSIS

    my $glue = Paws->service('Glue');
    my $GetCatalogImportStatusResponse = $glue->GetCatalogImportStatus(
      CatalogId => 'MyCatalogIdString',    # OPTIONAL
    );

    # Results:
    my $ImportStatus = $GetCatalogImportStatusResponse->ImportStatus;

    # Returns a L<Paws::Glue::GetCatalogImportStatusResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/glue/GetCatalogImportStatus>

=head1 ATTRIBUTES


=head2 CatalogId => Str

The ID of the catalog to migrate. Currently, this should be the AWS
account ID.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetCatalogImportStatus in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
